@@ -33,6 +33,7 @@
 #include <QtGui/QX11Info>
 
 #include "keyboard_config.h"
+#include "preview/keyboardpainter.h"
 #include "xkb_rules.h"
 #include "flags.h"
 #include "x11_helper.h"
@@ -335,6 +336,8 @@ void KCMKeyboardWidget::initializeLayoutsUI()
 	connect(uiWidget->moveUpBtn, SIGNAL(clicked(bool)), this, SLOT(moveUp()));
 	connect(uiWidget->moveDownBtn, SIGNAL(clicked(bool)), this, SLOT(moveDown()));
 
+    connect(uiWidget->previewbutton,SIGNAL(clicked(bool)),this,SLOT(previewLayout()));
+
 	connect(uiWidget->xkbGrpClearBtn, SIGNAL(clicked(bool)), this, SLOT(clearGroupShortcuts()));
 	connect(uiWidget->xkb3rdLevelClearBtn, SIGNAL(clicked(bool)), this, SLOT(clear3rdLevelShortcuts()));
 
@@ -360,6 +363,32 @@ void KCMKeyboardWidget::initializeLayoutsUI()
 	connect(uiWidget->layoutLoopCountSpinBox, SIGNAL(valueChanged(int)), this, SLOT(uiChanged()));
 }
 
+void KCMKeyboardWidget::previewLayout(){
+    QMessageBox q;
+    QModelIndex index = uiWidget->layoutsTableView->currentIndex() ;
+    QModelIndex idcountry = index.sibling(index.row(),0) ;
+    QString country=uiWidget->layoutsTableView->model()->data(idcountry).toString();
+    QModelIndex idvariant = index.sibling(index.row(),2) ;
+    QString variant=uiWidget->layoutsTableView->model()->data(idvariant).toString();
+    if(index.row()==-1 || index.column()==-1){
+        q.setText(i18n("No layout selected "));
+        q.exec();
+    }
+    else{
+        KeyboardPainter* layoutPreview = new KeyboardPainter();
+        const LayoutInfo* layoutInfo = rules->getLayoutInfo(country);
+        foreach(const VariantInfo* variantInfo, layoutInfo->variantInfos) {
+            if(variant==variantInfo->description){
+                variant=variantInfo->name;
+                break;
+            }
+        }
+        layoutPreview->generateKeyboardLayout(country,variant);
+        layoutPreview->exec();
+        layoutPreview->setModal(true);
+    }
+}
+
 void KCMKeyboardWidget::configureLayoutsChanged()
 {
 	if( uiWidget->layoutsGroupBox->isChecked()	&& keyboardConfig->layouts.isEmpty() ) {
@@ -388,6 +417,7 @@ void KCMKeyboardWidget::layoutSelectionChanged()
 	uiWidget->removeLayoutBtn->setEnabled( ! selected.isEmpty() );
 	QPair<int, int> rowsRange( getSelectedRowRange(selected) );
 	uiWidget->moveUpBtn->setEnabled( ! selected.isEmpty() && rowsRange.first > 0);
+    uiWidget->previewbutton->setEnabled(! selected.isEmpty());
 	uiWidget->moveDownBtn->setEnabled( ! selected.isEmpty() && rowsRange.second < keyboardConfig->layouts.size()-1 );
 }
 
