@@ -78,7 +78,7 @@ namespace Oxygen
     //__________________________________________________________
     void ExceptionListWidget::setExceptions( const ExceptionList& exceptions )
     {
-        model().set( ExceptionModel::List( exceptions.begin(), exceptions.end() ) );
+        model().set( exceptions );
         resizeColumns();
     }
 
@@ -88,7 +88,7 @@ namespace Oxygen
 
         ExceptionModel::List exceptions( model().get() );
         ExceptionList out;
-        for( ExceptionModel::List::const_iterator iter = exceptions.begin(); iter != exceptions.end(); ++iter )
+        for( ExceptionModel::List::const_iterator iter = exceptions.constBegin(); iter != exceptions.constEnd(); ++iter )
         { out.push_back( *iter ); }
         return out;
 
@@ -240,7 +240,7 @@ namespace Oxygen
         ExceptionModel::List currentException( model().get() );
         ExceptionModel::List newExceptions;
 
-        for( ExceptionModel::List::const_iterator iter = currentException.begin(); iter != currentException.end(); ++iter )
+        for( ExceptionModel::List::const_iterator iter = currentException.constBegin(); iter != currentException.constEnd(); ++iter )
         {
 
             // check if new list is not empty, current index is selected and last index is not.
@@ -252,10 +252,10 @@ namespace Oxygen
                 ) )
             {
                 Exception last( newExceptions.back() );
-                newExceptions.pop_back();
-                newExceptions.push_back( *iter );
-                newExceptions.push_back( last );
-            } else newExceptions.push_back( *iter );
+                newExceptions.removeLast();
+                newExceptions.append( *iter );
+                newExceptions.append( last );
+            } else newExceptions.append( *iter );
 
         }
 
@@ -263,7 +263,7 @@ namespace Oxygen
 
         // restore selection
         ui.exceptionListView->selectionModel()->select( model().index( selectedExceptions.front() ),  QItemSelectionModel::Clear|QItemSelectionModel::Select|QItemSelectionModel::Rows );
-        for( ExceptionModel::List::const_iterator iter = selectedExceptions.begin(); iter != selectedExceptions.end(); ++iter )
+        for( ExceptionModel::List::const_iterator iter = selectedExceptions.constBegin(); iter != selectedExceptions.constEnd(); ++iter )
         { ui.exceptionListView->selectionModel()->select( model().index( *iter ), QItemSelectionModel::Select|QItemSelectionModel::Rows ); }
 
         emit changed();
@@ -283,34 +283,38 @@ namespace Oxygen
         QModelIndexList selectedIndices( ui.exceptionListView->selectionModel()->selectedIndexes() );
         ExceptionModel::List selectedExceptions( model().get( selectedIndices ) );
 
-        ExceptionModel::List currentException( model().get() );
+        ExceptionModel::List currentExceptions( model().get() );
         ExceptionModel::List newExceptions;
 
-        for( ExceptionModel::List::reverse_iterator iter = currentException.rbegin(); iter != currentException.rend(); ++iter )
+        ExceptionModel::ListIterator iter( currentExceptions );
+        iter.toBack();
+        while( iter.hasPrevious() )
         {
 
+            const Exception& current( iter.previous() );
+
             // check if new list is not empty, current index is selected and last index is not.
             // if yes, move.
             if(
                 !( newExceptions.empty() ||
-                selectedIndices.indexOf( model().index( *iter ) ) == -1 ||
-                selectedIndices.indexOf( model().index( newExceptions.back() ) ) != -1
+                selectedIndices.indexOf( model().index( current ) ) == -1 ||
+                selectedIndices.indexOf( model().index( newExceptions.front() ) ) != -1
                 ) )
             {
 
-                Exception last( newExceptions.back() );
-                newExceptions.pop_back();
-                newExceptions.push_back( *iter );
-                newExceptions.push_back( last );
+                Exception first( newExceptions.front() );
+                newExceptions.removeFirst();
+                newExceptions.prepend( current );
+                newExceptions.prepend( first );
 
-            } else newExceptions.push_back( *iter );
+            } else newExceptions.prepend( current );
         }
 
-        model().set( ExceptionModel::List( newExceptions.rbegin(), newExceptions.rend() ) );
+        model().set( newExceptions );
 
         // restore selection
         ui.exceptionListView->selectionModel()->select( model().index( selectedExceptions.front() ),  QItemSelectionModel::Clear|QItemSelectionModel::Select|QItemSelectionModel::Rows );
-        for( ExceptionModel::List::const_iterator iter = selectedExceptions.begin(); iter != selectedExceptions.end(); ++iter )
+        for( ExceptionModel::List::const_iterator iter = selectedExceptions.constBegin(); iter != selectedExceptions.constEnd(); ++iter )
         { ui.exceptionListView->selectionModel()->select( model().index( *iter ), QItemSelectionModel::Select|QItemSelectionModel::Rows ); }
 
         emit changed();
