@@ -148,6 +148,12 @@ void FallApartEffect::slotWindowClosed(EffectWindow* c)
 {
     if (!isRealWindow(c))
         return;
+    if (c->isMinimized())
+        return;
+    if (!c->isOnCurrentDesktop())
+        return;
+    if (!c->isOnCurrentActivity())
+        return;
     const void* e = c->data(WindowClosedGrabRole).value<void*>();
     if (e && e != this)
         return;
