@@ -19,6 +19,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *********************************************************************/
 
 #include "resize.h"
+// KConfigSkeleton
+#include "resizeconfig.h"
 
 #include <kwinglutils.h>
 #ifdef KWIN_HAVE_XRENDER_COMPOSITING
@@ -27,7 +29,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #endif
 
 #include <KColorScheme>
-#include <KDE/KConfigGroup>
+
+#include <QtGui/QVector2D>
 
 namespace KWin
 {
@@ -67,12 +70,9 @@ void ResizeEffect::paintWindow(EffectWindow* w, int mask, QRegion region, Window
 {
     if (m_active && w == m_resizeWindow) {
         if (m_features & TextureScale) {
-            data.xTranslate += m_currentGeometry.x() - m_originalGeometry.x();
-            data.xScale *= m_currentGeometry.width();
-            data.xScale /= m_originalGeometry.width();
-            data.yTranslate += m_currentGeometry.y() - m_originalGeometry.y();
-            data.yScale *= m_currentGeometry.height();
-            data.yScale /= m_originalGeometry.height();
+            data += (m_currentGeometry.topLeft() - m_originalGeometry.topLeft());
+            data *= QVector2D(float(m_currentGeometry.width())/m_originalGeometry.width(),
+                              float(m_currentGeometry.height())/m_originalGeometry.height());
         }
         effects->paintWindow(w, mask, region, data);
 
@@ -82,13 +82,11 @@ void ResizeEffect::paintWindow(EffectWindow* w, int mask, QRegion region, Window
             float alpha = 0.8f;
             QColor color = KColorScheme(QPalette::Normal, KColorScheme::Selection).background().color();
 
-            if (effects->compositingType() == OpenGLCompositing) {
+            if (effects->isOpenGLCompositing()) {
                 GLVertexBuffer *vbo = GLVertexBuffer::streamingBuffer();
                 vbo->reset();
                 vbo->setUseColor(true);
-                if (ShaderManager::instance()->isValid()) {
-                    ShaderManager::instance()->pushShader(ShaderManager::ColorShader);
-                }
+                ShaderBinder binder(ShaderManager::ColorShader);
                 glEnable(GL_BLEND);
                 glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
                 color.setAlphaF(alpha);
@@ -105,9 +103,6 @@ void ResizeEffect::paintWindow(EffectWindow* w, int mask, QRegion region, Window
                 }
                 vbo->setData(verts.count() / 2, 2, verts.data(), NULL);
                 vbo->render(GL_TRIANGLES);
-                if (ShaderManager::instance()->isValid()) {
-                    ShaderManager::instance()->popShader();
-                }
                 glDisable(GL_BLEND);
             }
 
@@ -130,11 +125,11 @@ void ResizeEffect::paintWindow(EffectWindow* w, int mask, QRegion region, Window
 
 void ResizeEffect::reconfigure(ReconfigureFlags)
 {
-    KConfigGroup conf = effects->effectConfig("Resize");
     m_features = 0;
-    if (conf.readEntry("TextureScale", true))
+    ResizeConfig::self()->readConfig();
+    if (ResizeConfig::textureScale())
         m_features |= TextureScale;
-    if (conf.readEntry("Outline", false))
+    if (ResizeConfig::outline())
         m_features |= Outline;
 }
 
